@@ -21,6 +21,7 @@
 #include "ephy-embed-shell.h"
 
 #include "ephy-about-handler.h"
+#include "ephy-dbus-util.h"
 #include "ephy-debug.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-private.h"
@@ -56,14 +57,12 @@ typedef struct {
   EphyAboutHandler *about_handler;
   guint update_overview_timeout_id;
   guint hiding_overview_item;
-  GDBusConnection *bus;
+  GDBusServer *dbus_server;
   GList *web_extensions;
-  guint web_extensions_page_created_signal_id;
 } EphyEmbedShellPrivate;
 
 enum
 {
-  PREPARE_CLOSE,
   RESTORED_WINDOW,
   WEB_VIEW_CREATED,
   PAGE_CREATED,
@@ -106,32 +105,11 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->user_content);
   g_clear_object (&priv->downloads_manager);
   g_clear_object (&priv->web_context);
+  g_clear_object (&priv->dbus_server);
 
   G_OBJECT_CLASS (ephy_embed_shell_parent_class)->dispose (object);
 }
 
-static gint
-web_extension_compare (EphyWebExtensionProxy *proxy,
-                       const char *name_owner)
-{
-  return g_strcmp0 (ephy_web_extension_proxy_get_name_owner (proxy), name_owner);
-}
-
-static EphyWebExtensionProxy *
-ephy_embed_shell_find_web_extension (EphyEmbedShell *shell,
-                                     const char *name_owner)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  GList *l;
-
-  l = g_list_find_custom (priv->web_extensions, name_owner, (GCompareFunc)web_extension_compare);
-
-  if (!l)
-    g_warning ("Could not find extension with name owner `%s´.", name_owner);
-
-  return l ? EPHY_WEB_EXTENSION_PROXY (l->data) : NULL;
-}
-
 static void
 web_extension_form_auth_data_message_received_cb (WebKitUserContentManager *manager,
                                                   WebKitJavascriptResult *message,
@@ -154,26 +132,6 @@ web_extension_form_auth_data_message_received_cb (WebKitUserContentManager *mana
   g_variant_unref (variant);
 }
 
-static void
-web_extension_page_created (GDBusConnection *connection,
-                            const char *sender_name,
-                            const char *object_path,
-                            const char *interface_name,
-                            const char *signal_name,
-                            GVariant *parameters,
-                            EphyEmbedShell *shell)
-{
-  EphyWebExtensionProxy *web_extension;
-  guint64 page_id;
-
-  g_variant_get (parameters, "(t)", &page_id);
-
-  web_extension = ephy_embed_shell_find_web_extension (shell, sender_name);
-  if (!web_extension)
-    return;
-  g_signal_emit (shell, signals[PAGE_CREATED], 0, page_id, web_extension);
-}
-
 static void
 history_service_query_urls_cb (EphyHistoryService *service,
                                gboolean success,
@@ -203,6 +161,7 @@ ephy_embed_shell_update_overview_urls (EphyEmbedShell *shell)
   query->sort_type = EPHY_HISTORY_SORT_MOST_VISITED;
   query->limit = EPHY_ABOUT_OVERVIEW_MAX_ITEMS;
   query->ignore_hidden = TRUE;
+  query->ignore_local = TRUE;
 
   ephy_history_service_query_urls (priv->global_history_service, query, NULL,
                                    (EphyHistoryJobCallback) history_service_query_urls_cb,
@@ -299,40 +258,6 @@ web_extension_about_apps_message_received_cb (WebKitUserContentManager *manager,
   g_free (app_id);
 }
 
-static void
-web_extension_destroyed (EphyEmbedShell *shell,
-                         GObject *web_extension)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  priv->web_extensions = g_list_remove (priv->web_extensions, web_extension);
-}
-
-static void
-ephy_embed_shell_watch_web_extension (EphyEmbedShell *shell,
-                                      const char *web_extension_id)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  EphyWebExtensionProxy *web_extension;
-  char *service_name;
-
-  if (!priv->bus)
-    return;
-
-  service_name = g_strdup_printf ("%s-%s", EPHY_WEB_EXTENSION_SERVICE_NAME, web_extension_id);
-  web_extension = ephy_web_extension_proxy_new (priv->bus, service_name);
-  priv->web_extensions = g_list_prepend (priv->web_extensions, web_extension);
-  g_object_weak_ref (G_OBJECT (web_extension), (GWeakNotify)web_extension_destroyed, shell);
-  g_free (service_name);
-}
-
-static void
-ephy_embed_shell_unwatch_web_extension (EphyWebExtensionProxy *web_extension,
-                                        EphyEmbedShell *shell)
-{
-  g_object_weak_unref (G_OBJECT (web_extension), (GWeakNotify)web_extension_destroyed, shell);
-}
-
 static void
 history_service_url_title_changed_cb (EphyHistoryService *service,
                                       const char *url,
@@ -478,12 +403,6 @@ ephy_embed_shell_get_encodings (EphyEmbedShell *shell)
   return G_OBJECT (priv->encodings);
 }
 
-void
-ephy_embed_shell_prepare_close (EphyEmbedShell *shell)
-{
-  g_signal_emit (shell, signals[PREPARE_CLOSE], 0);
-}
-
 void
 ephy_embed_shell_restored_window (EphyEmbedShell *shell)
 {
@@ -524,6 +443,32 @@ ephy_resource_request_cb (WebKitURISchemeRequest *request)
   }
 }
 
+static void
+web_extension_destroyed (EphyEmbedShell *shell,
+                         GObject *web_extension)
+{
+  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
+
+  priv->web_extensions = g_list_remove (priv->web_extensions, web_extension);
+}
+
+static void
+ephy_embed_shell_watch_web_extension (EphyEmbedShell *shell,
+                                      EphyWebExtensionProxy *web_extension)
+{
+  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
+
+  priv->web_extensions = g_list_prepend (priv->web_extensions, web_extension);
+  g_object_weak_ref (G_OBJECT (web_extension), (GWeakNotify)web_extension_destroyed, shell);
+}
+
+static void
+ephy_embed_shell_unwatch_web_extension (EphyWebExtensionProxy *web_extension,
+                                        EphyEmbedShell *shell)
+{
+  g_object_weak_unref (G_OBJECT (web_extension), (GWeakNotify)web_extension_destroyed, shell);
+}
+
 static void
 initialize_web_extensions (WebKitWebContext* web_context,
                            EphyEmbedShell *shell)
@@ -531,41 +476,97 @@ initialize_web_extensions (WebKitWebContext* web_context,
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   GVariant *user_data;
   gboolean private_profile;
-  char *web_extension_id;
-  static guint web_extension_count = 0;
+  const char *address;
 
   webkit_web_context_set_web_extensions_directory (web_context, EPHY_WEB_EXTENSIONS_DIR);
 
-  web_extension_id = g_strdup_printf ("%u-%u", getpid (), ++web_extension_count);
-  ephy_embed_shell_watch_web_extension (shell, web_extension_id);
+  address = priv->dbus_server ? g_dbus_server_get_client_address (priv->dbus_server) : NULL;
 
   private_profile = EPHY_EMBED_SHELL_MODE_HAS_PRIVATE_PROFILE (priv->mode);
-  user_data = g_variant_new ("(ssb)", web_extension_id, ephy_dot_dir (), private_profile);
+  user_data = g_variant_new ("(mssb)",
+                             address,
+                             ephy_dot_dir (),
+                             private_profile);
   webkit_web_context_set_web_extensions_initialization_user_data (web_context, user_data);
 }
 
 static void
-ephy_embed_shell_setup_web_extensions_connection (EphyEmbedShell *shell)
+web_extension_page_created (EphyWebExtensionProxy *extension,
+                            guint64 page_id,
+                            EphyEmbedShell *shell)
+{
+  g_signal_emit (shell, signals[PAGE_CREATED], 0, page_id, extension);
+}
+
+static gboolean
+new_connection_cb (GDBusServer *server,
+                   GDBusConnection *connection,
+                   EphyEmbedShell *shell)
+{
+  EphyWebExtensionProxy *extension = ephy_web_extension_proxy_new (connection);
+  ephy_embed_shell_watch_web_extension (shell, extension);
+
+  g_signal_connect_object (extension, "page-created",
+                           G_CALLBACK (web_extension_page_created), shell, 0);
+
+  return TRUE;
+}
+
+static gboolean
+authorize_authenticated_peer_cb (GDBusAuthObserver *observer,
+                                 GIOStream *stream,
+                                 GCredentials *credentials,
+                                 EphyEmbedShell *shell)
+{
+  return ephy_dbus_peer_is_authorized (credentials);
+}
+
+static void
+ephy_embed_shell_setup_web_extensions_server (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
+  GDBusAuthObserver *observer;
+  char *address;
+  char *guid;
+  GError *error = NULL;
 
-  priv->bus = g_application_get_dbus_connection (G_APPLICATION (shell));
-  if (!priv->bus) {
-    g_warning ("Application not connected to session bus");
-    return;
+  /* On Linux, this creates an abstract socket with a name that unnecessarily
+   * begins with the tmp dir. Where abstract sockets are unavailable, it
+   * actually creates the socket under the tmp dir. */
+  address = g_strdup_printf ("unix:tmpdir=%s", g_get_tmp_dir ());
+
+  guid = g_dbus_generate_guid ();
+  observer = g_dbus_auth_observer_new ();
+
+  g_signal_connect (observer, "authorize-authenticated-peer",
+                    G_CALLBACK (authorize_authenticated_peer_cb), shell);
+
+  /* Why sync?
+   *
+   * (a) The server must be started before web extensions try to connect.
+   * (b) Gio actually has no async version. Don't know why.
+   */
+  priv->dbus_server = g_dbus_server_new_sync (address,
+                                              G_DBUS_SERVER_FLAGS_NONE,
+                                              guid,
+                                              observer,
+                                              NULL,
+                                              &error);
+
+  if (error) {
+    g_warning ("Failed to start web extension server on %s: %s", address, error->message);
+    g_error_free (error);
+    goto out;
   }
 
-  priv->web_extensions_page_created_signal_id =
-    g_dbus_connection_signal_subscribe (priv->bus,
-                                        NULL,
-                                        EPHY_WEB_EXTENSION_INTERFACE,
-                                        "PageCreated",
-                                        EPHY_WEB_EXTENSION_OBJECT_PATH,
-                                        NULL,
-                                        G_DBUS_SIGNAL_FLAGS_NONE,
-                                        (GDBusSignalCallback)web_extension_page_created,
-                                        shell,
-                                        NULL);
+  g_signal_connect (priv->dbus_server, "new-connection",
+                    G_CALLBACK (new_connection_cb), shell);
+  g_dbus_server_start (priv->dbus_server);
+
+out:
+  g_free (address);
+  g_free (guid);
+  g_object_unref (observer);
 }
 
 static void
@@ -587,6 +588,8 @@ ephy_embed_shell_setup_process_model (EphyEmbedShell *shell)
   case EPHY_PREFS_PROCESS_MODEL_ONE_SECONDARY_PROCESS_PER_WEB_VIEW:
     max_processes = g_settings_get_uint (EPHY_SETTINGS_MAIN, EPHY_PREFS_MAX_PROCESSES);
     break;
+  default:
+    g_assert_not_reached ();
   }
 
   webkit_web_context_set_process_model (priv->web_context, WEBKIT_PROCESS_MODEL_MULTIPLE_SECONDARY_PROCESSES);
@@ -594,9 +597,9 @@ ephy_embed_shell_setup_process_model (EphyEmbedShell *shell)
 }
 
 static void
-ephy_embed_shell_create_web_context (EphyEmbedShell *embed_shell)
+ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
 {
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (embed_shell);
+  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   WebKitWebsiteDataManager *manager;
   char *data_dir;
   char *cache_dir;
@@ -635,7 +638,7 @@ ephy_embed_shell_startup (GApplication* application)
   if (priv->mode != EPHY_EMBED_SHELL_MODE_TEST)
     ephy_embed_shell_create_web_context (embed_shell);
 
-  ephy_embed_shell_setup_web_extensions_connection (shell);
+  ephy_embed_shell_setup_web_extensions_server (shell);
 
   /* User content manager */
   if (priv->mode != EPHY_EMBED_SHELL_MODE_TEST)
@@ -717,16 +720,14 @@ ephy_embed_shell_shutdown (GApplication* application)
 
   G_APPLICATION_CLASS (ephy_embed_shell_parent_class)->shutdown (application);
 
+  if (priv->dbus_server)
+    g_dbus_server_stop (priv->dbus_server);
+
   webkit_user_content_manager_unregister_script_message_handler (priv->user_content, "overview");
   webkit_user_content_manager_unregister_script_message_handler (priv->user_content, "tlsErrorPage");
   webkit_user_content_manager_unregister_script_message_handler (priv->user_content, "formAuthData");
   webkit_user_content_manager_unregister_script_message_handler (priv->user_content, "aboutApps");
 
-  if (priv->web_extensions_page_created_signal_id > 0) {
-    g_dbus_connection_signal_unsubscribe (priv->bus, priv->web_extensions_page_created_signal_id);
-    priv->web_extensions_page_created_signal_id = 0;
-  }
-
   g_list_foreach (priv->web_extensions, (GFunc)ephy_embed_shell_unwatch_web_extension, application);
 
   g_object_unref (ephy_embed_prefs_get_settings ());
@@ -770,18 +771,18 @@ ephy_embed_shell_get_property (GObject *object,
 static void
 ephy_embed_shell_constructed (GObject *object)
 {
-  EphyEmbedShell *embed_shell;
+  EphyEmbedShell *shell;
   EphyEmbedShellPrivate *priv;
 
   G_OBJECT_CLASS (ephy_embed_shell_parent_class)->constructed (object);
 
-  embed_shell = EPHY_EMBED_SHELL (object);
-  priv = ephy_embed_shell_get_instance_private (embed_shell);
+  shell = EPHY_EMBED_SHELL (object);
+  priv = ephy_embed_shell_get_instance_private (shell);
   /* These do not run the EmbedShell application instance, so make sure that
      there is a web context and a user content manager for them. */
-  if (ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_TEST ||
-      ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER) {
-    ephy_embed_shell_create_web_context (embed_shell);
+  if (ephy_embed_shell_get_mode (shell) == EPHY_EMBED_SHELL_MODE_TEST ||
+      ephy_embed_shell_get_mode (shell) == EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER) {
+    ephy_embed_shell_create_web_context (shell);
     priv->user_content = webkit_user_content_manager_new ();
   }
 }
@@ -820,22 +821,6 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
                                      N_PROPERTIES,
                                      object_properties);
 
-/**
- * EphyEmbed::prepare-close:
- * @shell: the #EphyEmbedShell
- * 
- * The ::prepare-close signal is emitted when epiphany is preparing to
- * quit on command from the session manager. You can use it when you need
- * to do something special (shut down a service, for example).
- **/
-  signals[PREPARE_CLOSE] =
-    g_signal_new ("prepare-close",
-                  EPHY_TYPE_EMBED_SHELL,
-                  G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (EphyEmbedShellClass, prepare_close),
-                  NULL, NULL, NULL,
-                  G_TYPE_NONE, 0);
-
 /**
  * EphyEmbedShell::finished-restoring-window:
  * @shell: the #EphyEmbedShell
