@@ -16,9 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -242,8 +240,12 @@ ephy_embed_utils_autosearch_address (const char *search_key)
   }
 
   query_param = soup_form_encode ("q", search_key, NULL);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+  /* Format string under control of user input... but gsettings is trusted input. */
   /* + 2 here is getting rid of 'q=' */
   effective_address = g_strdup_printf (url_search, query_param + 2);
+#pragma GCC diagnostic pop
   g_free (query_param);
   g_free (url_search);
 
@@ -322,12 +324,26 @@ ephy_embed_utils_urls_have_same_origin (const char *a_url,
     return retval;
 
   b_uri = soup_uri_new (b_url);
-  if (b_uri) {
-    retval = a_uri->host && b_uri->host && soup_uri_host_equal (a_uri, b_uri);
-    soup_uri_free (b_uri);
+  if (!b_uri) {
+    soup_uri_free (a_uri);
+    return retval;
+  }
+
+  if (a_uri->host && b_uri->host) {
+    retval = soup_uri_host_equal (a_uri, b_uri);
+    if (!retval) {
+      const char *a_domain;
+      const char *b_domain;
+
+      a_domain = soup_tld_get_base_domain (a_uri->host, NULL);
+      b_domain = soup_tld_get_base_domain (b_uri->host, NULL);
+
+      retval = a_domain && b_domain && strcmp (a_domain, b_domain) == 0;
+    }
   }
 
   soup_uri_free (a_uri);
+  soup_uri_free (b_uri);
 
   return retval;
 }
