@@ -113,6 +113,8 @@ struct _EphyWebView {
   gboolean loading_error_page;
   char *tls_error_failing_uri;
 
+  EphyWebViewErrorPage error_page;
+
   /* Web Extension */
   EphyWebExtensionProxy *web_extension;
 };
@@ -1407,10 +1409,8 @@ update_security_status_for_committed_load (EphyWebView *view,
   WebKitSecurityManager *security_manager;
   SoupURI *soup_uri;
 
-  if (view->loading_error_page) {
-    view->loading_error_page = FALSE;
+  if (view->loading_error_page)
     return;
-  }
 
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (view));
   if (EPHY_IS_EMBED_CONTAINER (toplevel))
@@ -1502,6 +1502,11 @@ load_changed_cb (WebKitWebView *web_view,
       g_free (history_uri);
     }
 
+    if (view->loading_error_page)
+        view->loading_error_page = FALSE;
+    else
+        view->error_page = EPHY_WEB_VIEW_ERROR_PAGE_NONE;
+
     break;
   }
   case WEBKIT_LOAD_FINISHED:
@@ -1685,6 +1690,22 @@ get_tls_error_page_message (EphyWebView *view, const char *hostname)
   return msg;
 }
 
+/**
+ * ephy_web_view_get_error_page:
+ * @view: an #EphyWebView
+ *
+ * Returns the error page currently displayed, or
+ * %EPHY_WEB_VIEW_ERROR_PAGE_NONE.
+ *
+ **/
+EphyWebViewErrorPage
+ephy_web_view_get_error_page (EphyWebView *view)
+{
+  g_return_val_if_fail (EPHY_IS_WEB_VIEW (view), EPHY_WEB_VIEW_ERROR_PAGE_NONE);
+
+  return view->error_page;
+}
+
 /**
  * ephy_web_view_load_error_page:
  * @view: an #EphyWebView
@@ -1715,7 +1736,10 @@ ephy_web_view_load_error_page (EphyWebView *view,
   const char *accesskey;
   GBytes *html_file;
 
+  g_return_if_fail (page != EPHY_WEB_VIEW_ERROR_PAGE_NONE);
+
   view->loading_error_page = TRUE;
+  view->error_page = page;
 
   if (page == EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE)
     ephy_web_view_set_security_level (view, EPHY_SECURITY_LEVEL_UNACCEPTABLE_CERTIFICATE);
@@ -1749,10 +1773,10 @@ ephy_web_view_load_error_page (EphyWebView *view,
                                "address. You may wish to verify that your "
                                "internet connection is working correctly.</p>"),
                              uri, reason);
-      button_label = g_strdup (_("Try Again"));
+      button_label = g_strdup (_("Reload"));
       custom_class = "network-error";
-      /* Access key for the "Try Again" button on the network error page. */
-      accesskey = dgettext ("accesskey", "A");
+      /* Access key for the "Reload" button on the network error page. */
+      accesskey = C_("reload-access-key", "R");
       break;
     case EPHY_WEB_VIEW_ERROR_PAGE_CRASH:
       page_title = g_strdup_printf (_("Problem loading “%s”"), hostname);
@@ -1763,19 +1787,19 @@ ephy_web_view_load_error_page (EphyWebView *view,
                                "please report the problem to the "
                                "<strong>%s</strong> developers.</p>"),
                              LSB_DISTRIBUTOR);
-      button_label = g_strdup (_("Reload Anyway"));
+      button_label = g_strdup (_("Reload"));
       custom_class = "page-crash";
-      /* Access key for the "Reload Anyway" button on the crash error page. */
-      accesskey = dgettext ("accesskey", "A");
+      /* Access key for the "Reload" button on the crash error page. */
+      accesskey = C_("reload-access-key", "R");
       break;
     case EPHY_WEB_VIEW_ERROR_PROCESS_CRASH:
       page_title = g_strdup_printf (_("Problem displaying “%s”"), hostname);
       msg_title = g_strdup (_("Oops!"));
       msg = g_strdup (_("Something went wrong while displaying this page. Please reload or visit a different page to continue."));
-      button_label = g_strdup (_("Reload Anyway"));
+      button_label = g_strdup (_("Reload"));
       custom_class = "process-crash";
-      /* Access key for the "Reload Anyway" button on the crash error page. */
-      accesskey = dgettext ("accesskey", "A");
+      /* Access key for the "Reload" button on the crash error page. */
+      accesskey = C_("reload-access-key", "R");
       break;
     case EPHY_WEB_VIEW_ERROR_INVALID_TLS_CERTIFICATE:
       /* Page title when a site cannot be loaded. %s is the site's hostname. */
@@ -1784,13 +1808,14 @@ ephy_web_view_load_error_page (EphyWebView *view,
       msg_title = g_strdup (_("Look out!"));
       msg = get_tls_error_page_message (view, hostname);
       /* Button on error page when a website's TLS certificate is invalid. */
-      button_label = g_strdup (_("Load Anyway"));
+      button_label = g_strdup (_("Accept Risk"));
       custom_class = "tls-error";
-      /* Access key for the "Load Anyway" button on the TLS error page. */
-      accesskey = dgettext ("accesskey", "A");
+      /* Access key for the "Accept Risk" button on the TLS error page. */
+      accesskey = C_("accept-risk-access-key", "R");
       load_anyway_js = g_strdup_printf ("window.webkit.messageHandlers.tlsErrorPage.postMessage(%"G_GUINT64_FORMAT");",
                                         webkit_web_view_get_page_id (WEBKIT_WEB_VIEW (view)));
       break;
+    case EPHY_WEB_VIEW_ERROR_PAGE_NONE:
     default:
       g_assert_not_reached ();
   }
