@@ -26,32 +26,12 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_TYPE_SNAPSHOT_SERVICE            (ephy_snapshot_service_get_type())
-#define EPHY_SNAPSHOT_SERVICE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EPHY_TYPE_SNAPSHOT_SERVICE, EphySnapshotService))
-#define EPHY_SNAPSHOT_SERVICE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), EPHY_TYPE_SNAPSHOT_SERVICE, EphySnapshotServiceClass))
-#define EPHY_IS_SNAPSHOT_SERVICE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EPHY_TYPE_SNAPSHOT_SERVICE))
-#define EPHY_IS_SNAPSHOT_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EPHY_TYPE_SNAPSHOT_SERVICE))
-#define EPHY_SNAPSHOT_SERVICE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), EPHY_TYPE_SNAPSHOT_SERVICE, EphySnapshotServiceClass))
+#define EPHY_TYPE_SNAPSHOT_SERVICE (ephy_snapshot_service_get_type ())
+
+G_DECLARE_FINAL_TYPE (EphySnapshotService, ephy_snapshot_service, EPHY, SNAPSHOT_SERVICE, GObject)
 
 #define EPHY_SNAPSHOT_SERVICE_ERROR           (ephy_snapshot_service_error_quark())
 
-typedef struct _EphySnapshotService        EphySnapshotService;
-typedef struct _EphySnapshotServiceClass   EphySnapshotServiceClass;
-typedef struct _EphySnapshotServicePrivate EphySnapshotServicePrivate;
-
-struct _EphySnapshotService
-{
-  GObject parent;
-
-  /*< private >*/
-  EphySnapshotServicePrivate *priv;
-};
-
-struct _EphySnapshotServiceClass
-{
-  GObjectClass parent_class;
-};
-
 typedef enum {
   EPHY_SNAPSHOT_SERVICE_ERROR_NOT_FOUND,
   EPHY_SNAPSHOT_SERVICE_ERROR_WEB_VIEW,
@@ -62,7 +42,6 @@ typedef enum {
 #define EPHY_THUMBNAIL_WIDTH 180
 #define EPHY_THUMBNAIL_HEIGHT 135
 
-GType                ephy_snapshot_service_get_type                    (void) G_GNUC_CONST;
 GQuark               ephy_snapshot_service_error_quark                 (void);
 
 EphySnapshotService *ephy_snapshot_service_get_default                 (void);
