@@ -29,10 +29,12 @@
 #include "ephy-gui.h"
 #include "ephy-lib-type-builtins.h"
 #include "ephy-signal-accumulator.h"
+#include "ephy-uri-helpers.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <libgd/gd.h>
 #include <string.h>
 #if 0
 /* FIXME: Refactor the DNS prefetch, this is a layering violation */
@@ -48,10 +50,10 @@
  * #EphyLocationEntry implements the location bar in the main Epiphany window.
  */
 
-#define EPHY_LOCATION_ENTRY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_LOCATION_ENTRY, EphyLocationEntryPrivate))
-
-struct _EphyLocationEntryPrivate
+struct _EphyLocationEntry
 {
+	GtkEntry parent_instance;
+
 	GdkPixbuf *favicon;
 	GtkTreeModel *model;
 
@@ -86,9 +88,9 @@ struct _EphyLocationEntryPrivate
 
 static const GtkTargetEntry url_drag_types [] =
 {
-	{ EPHY_DND_URL_TYPE,        0, 0 },
-	{ EPHY_DND_URI_LIST_TYPE,   0, 1 },
-	{ EPHY_DND_TEXT_TYPE,       0, 2 }
+	{ (char *)EPHY_DND_URL_TYPE,        0, 0 },
+	{ (char *)EPHY_DND_URI_LIST_TYPE,   0, 1 },
+	{ (char *)EPHY_DND_TEXT_TYPE,       0, 2 }
 };
 
 static gboolean ephy_location_entry_reset_internal (EphyLocationEntry *, gboolean);
@@ -105,8 +107,10 @@ enum
 	PROP_LOCATION,
 	PROP_FAVICON,
 	PROP_SECURITY_LEVEL,
-	PROP_SHOW_FAVICON
+	PROP_SHOW_FAVICON,
+	LAST_PROP
 };
+static GParamSpec *obj_properties[LAST_PROP];
 
 enum signalsEnum
 {
@@ -173,18 +177,17 @@ static void
 ephy_location_entry_finalize (GObject *object)
 {
 	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (object);
-	EphyLocationEntryPrivate *priv = entry->priv;
-	
-	g_free (priv->saved_text);
 
-	if (priv->drag_targets != NULL)
+	g_free (entry->saved_text);
+
+	if (entry->drag_targets != NULL)
 	{
-		gtk_target_list_unref (priv->drag_targets);
+		gtk_target_list_unref (entry->drag_targets);
 	}
 
-	if (priv->favicon != NULL)
+	if (entry->favicon != NULL)
 	{
-		g_object_unref (priv->favicon);
+		g_object_unref (entry->favicon);
 	}
 
 	G_OBJECT_CLASS (ephy_location_entry_parent_class)->finalize (object);
@@ -202,66 +205,105 @@ ephy_location_entry_get_preferred_width (GtkWidget       *widget,
 		*natural_width = 848;
 }
 
+static void
+ephy_location_entry_copy_clipboard (GtkEntry *entry)
+{
+	char *text;
+	gint start;
+	gint end;
+
+	if (!gtk_editable_get_selection_bounds (GTK_EDITABLE (entry), &start, &end))
+		return;
+
+	text = gtk_editable_get_chars (GTK_EDITABLE (entry), start, end);
+
+	if (start == 0)
+	{
+		char *tmp = text;
+		text = ephy_uri_normalize (tmp);
+		g_free (tmp);
+	}
+
+	gtk_clipboard_set_text (gtk_widget_get_clipboard (GTK_WIDGET (entry),
+							  GDK_SELECTION_CLIPBOARD),
+							  text, -1);
+	g_free (text);
+}
+
+static void
+ephy_location_entry_cut_clipboard (GtkEntry *entry)
+{
+	if (!gtk_editable_get_editable (GTK_EDITABLE (entry)))
+	{
+		gtk_widget_error_bell (GTK_WIDGET (entry));
+		return;
+	}
+
+	ephy_location_entry_copy_clipboard (entry);
+	gtk_editable_delete_selection (GTK_EDITABLE (entry));
+}
+
 static void
 ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+	GtkEntryClass *entry_class = GTK_ENTRY_CLASS (klass);
 
 	object_class->get_property = ephy_location_entry_get_property;
 	object_class->set_property = ephy_location_entry_set_property;
 	object_class->finalize = ephy_location_entry_finalize;
 	widget_class->get_preferred_width = ephy_location_entry_get_preferred_width;
+	entry_class->copy_clipboard = ephy_location_entry_copy_clipboard;
+	entry_class->cut_clipboard = ephy_location_entry_cut_clipboard;
 
 	/**
 	* EphyLocationEntry:location:
 	*
 	* The current location.
 	*/
-	g_object_class_install_property (object_class,
-					 PROP_LOCATION,
-					 g_param_spec_string ("location",
-							      "Location",
-							      "The current location",
-							      "",
-							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	obj_properties[PROP_LOCATION] =
+		g_param_spec_string ("location",
+		                     "Location",
+		                     "The current location",
+		                     "",
+		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	/**
 	* EphyLocationEntry:favicon:
 	*
 	* The icon corresponding to the current location.
 	*/
-	g_object_class_install_property (object_class,
-					 PROP_FAVICON,
-					 g_param_spec_object ("favicon",
-							      "Favicon",
-							      "The icon corresponding to the current location",
-							      GDK_TYPE_PIXBUF,
-							      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	obj_properties[PROP_FAVICON] =
+		g_param_spec_object ("favicon",
+		                     "Favicon",
+		                     "The icon corresponding to the current location",
+		                     GDK_TYPE_PIXBUF,
+		                     G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
 	/**
 	* EphyLocationEntry:security-level:
 	*
 	* State of the security icon.
 	*/
-	g_object_class_install_property (object_class,
-					 PROP_SECURITY_LEVEL,
-					 g_param_spec_enum  ("security-level",
-							     "Security level",
-							     "State of the security icon",
-							     EPHY_TYPE_SECURITY_LEVEL,
-							     EPHY_SECURITY_LEVEL_TO_BE_DETERMINED,
-							     G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	obj_properties[PROP_SECURITY_LEVEL] =
+		g_param_spec_enum  ("security-level",
+		                    "Security level",
+		                    "State of the security icon",
+		                    EPHY_TYPE_SECURITY_LEVEL,
+		                    EPHY_SECURITY_LEVEL_TO_BE_DETERMINED,
+		                    G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
-	g_object_class_install_property (object_class,
-					 PROP_SHOW_FAVICON,
-					 g_param_spec_boolean ("show-favicon",
-							       "Show Favicon",
-							       "Whether to show the favicon",
-							       TRUE,
-							       G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	obj_properties[PROP_SHOW_FAVICON] =
+		g_param_spec_boolean ("show-favicon",
+		                      "Show Favicon",
+		                      "Whether to show the favicon",
+		                      TRUE,
+		                      G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
-       /**
+	g_object_class_install_properties (object_class, LAST_PROP, obj_properties);
+
+	/**
 	* EphyLocationEntry::user-changed:
 	* @entry: the object on which the signal is emitted
 	*
@@ -271,9 +313,7 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 	signals[USER_CHANGED] = g_signal_new (
 		"user_changed", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (EphyLocationEntryClass, user_changed),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
+		0, NULL, NULL, NULL,
 		G_TYPE_NONE,
 		0,
 		G_TYPE_NONE);
@@ -290,9 +330,7 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 		"lock-clicked",
 		EPHY_TYPE_LOCATION_ENTRY,
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (EphyLocationEntryClass, lock_clicked),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
+		0, NULL, NULL, NULL,
 		G_TYPE_NONE,
 		0);
 
@@ -309,9 +347,8 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 	signals[GET_LOCATION] = g_signal_new (
 		"get-location", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (EphyLocationEntryClass, get_location),
-		ephy_signal_accumulator_string, NULL,
-		g_cclosure_marshal_generic,
+		0, ephy_signal_accumulator_string,
+		NULL, NULL,
 		G_TYPE_STRING,
 		0,
 		G_TYPE_NONE);
@@ -329,43 +366,38 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 	signals[GET_TITLE] = g_signal_new (
 		"get-title", G_OBJECT_CLASS_TYPE (klass),
 		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (EphyLocationEntryClass, get_title),
-		ephy_signal_accumulator_string, NULL,
-		g_cclosure_marshal_generic,
+		0, ephy_signal_accumulator_string,
+		NULL, NULL,
 		G_TYPE_STRING,
 		0,
 		G_TYPE_NONE);
-
-	g_type_class_add_private (object_class, sizeof (EphyLocationEntryPrivate));
 }
 
 static void
 update_address_state (EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
 	const char *text;
 
 	text = gtk_entry_get_text (GTK_ENTRY (entry));
-	priv->original_address = text != NULL &&
-				 g_str_hash (text) == priv->hash;
+	entry->original_address = text != NULL &&
+				  g_str_hash (text) == entry->hash;
 }
 
 static void
 update_favicon (EphyLocationEntry *lentry)
 {
-	EphyLocationEntryPrivate *priv = lentry->priv;
 	GtkEntry *entry = GTK_ENTRY (lentry);
 
 	/* Only show the favicon if the entry's text is the
 	 * address of the current page.
 	 */
-	if (priv->show_favicon && priv->favicon != NULL && priv->original_address)
+	if (lentry->show_favicon && lentry->favicon != NULL && lentry->original_address)
 	{
 		gtk_entry_set_icon_from_pixbuf (entry,
 						GTK_ENTRY_ICON_PRIMARY,
-						priv->favicon);
+						lentry->favicon);
 	}
-	else if (priv->show_favicon)
+	else if (lentry->show_favicon)
 	{
 		const char *icon_name;
 
@@ -394,18 +426,16 @@ static void
 editable_changed_cb (GtkEditable *editable,
 		     EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-
 	update_address_state (entry);
 
-	if (priv->block_update == TRUE) 
+	if (entry->block_update == TRUE)
 		return;
 	else
 	{
-		priv->user_changed = TRUE;
-		priv->can_redo = FALSE;
-	}	
-	
+		entry->user_changed = TRUE;
+		entry->can_redo = FALSE;
+	}
+
 	g_signal_emit (entry, signals[USER_CHANGED], 0);
 }
 
@@ -439,8 +469,6 @@ entry_key_press_after_cb (GtkEntry *entry,
 			  GdkEventKey *event,
 			  EphyLocationEntry *lentry)
 {
-	EphyLocationEntryPrivate *priv = lentry->priv;
-
 	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
 
 	if ((event->keyval == GDK_KEY_Return ||
@@ -451,21 +479,21 @@ entry_key_press_after_cb (GtkEntry *entry,
 	{
 		//gtk_im_context_reset (entry->im_context);
 
-		priv->needs_reset = TRUE;
+		lentry->needs_reset = TRUE;
 		g_signal_emit_by_name (entry, "activate");
 
 		return TRUE;
 	}
-	
+
 	if ((event->keyval == GDK_KEY_Down || event->keyval == GDK_KEY_KP_Down)
 	    && state == 0)
 	{
 		/* If we are focusing the entry, with the cursor at the end of it
 		 * we emit the changed signal, so that the completion popup appears */
 		const char *string;
-		
+
 		string = gtk_entry_get_text (entry);
-		if (gtk_editable_get_position (GTK_EDITABLE (entry)) == strlen (string))
+		if (gtk_editable_get_position (GTK_EDITABLE (entry)) == (int)strlen (string))
 		{
 			g_signal_emit_by_name (entry, "changed", 0);
 			return TRUE;
@@ -479,14 +507,12 @@ static void
 entry_activate_after_cb (GtkEntry *entry,
 			 EphyLocationEntry *lentry)
 {
-	EphyLocationEntryPrivate *priv = lentry->priv;
-	
-	priv->user_changed = FALSE;
+	lentry->user_changed = FALSE;
 
-	if (priv->needs_reset)
+	if (lentry->needs_reset)
 	{
 		ephy_location_entry_reset_internal (lentry, TRUE);
-		priv->needs_reset = FALSE;
+		lentry->needs_reset = FALSE;
 	}
 }
 
@@ -496,18 +522,17 @@ match_selected_cb (GtkEntryCompletion *completion,
 		   GtkTreeIter *iter,
 		   EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
 	char *item = NULL;
 	guint state;
 
 	gtk_tree_model_get (model, iter,
-			    priv->action_col, &item, -1);
+			    entry->action_col, &item, -1);
 	if (item == NULL) return FALSE;
 
 	ephy_gui_get_current_event (NULL, &state, NULL);
 
-	priv->needs_reset = (state == GDK_CONTROL_MASK ||
-			     state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK));
+	entry->needs_reset = (state == GDK_CONTROL_MASK ||
+			      state == (GDK_CONTROL_MASK | GDK_SHIFT_MASK));
 
 	ephy_location_entry_set_location (entry, item);
 	//gtk_im_context_reset (GTK_ENTRY (entry)->im_context);
@@ -558,12 +583,10 @@ static void
 entry_clear_activate_cb (GtkMenuItem *item,
 			 EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-
-	priv->block_update = TRUE;
+	entry->block_update = TRUE;
 	gtk_entry_set_text (GTK_ENTRY (entry), "");
-	priv->block_update = FALSE;
-	priv->user_changed = TRUE;
+	entry->block_update = FALSE;
+	entry->user_changed = TRUE;
 }
 
 static void
@@ -585,7 +608,6 @@ entry_populate_popup_cb (GtkEntry *entry,
 			 GtkMenu *menu,
 			 EphyLocationEntry *lentry)
 {
-	EphyLocationEntryPrivate *priv = lentry->priv;
 	GtkWidget *clear_menuitem, *undo_menuitem, *redo_menuitem, *separator;
 	GList *children, *item;
 	int pos = 0, sep = 0;
@@ -613,21 +635,21 @@ entry_populate_popup_cb (GtkEntry *entry,
 	}
 
 	gtk_menu_shell_insert (GTK_MENU_SHELL (menu), clear_menuitem, pos - 1);
-	
+
 	undo_menuitem = gtk_menu_item_new_with_mnemonic (_("_Undo"));
-	gtk_widget_set_sensitive (undo_menuitem, priv->user_changed);
+	gtk_widget_set_sensitive (undo_menuitem, lentry->user_changed);
 	g_signal_connect (undo_menuitem, "activate",
 			  G_CALLBACK (entry_undo_activate_cb), lentry);
 	gtk_widget_show (undo_menuitem);
 	gtk_menu_shell_insert (GTK_MENU_SHELL (menu), undo_menuitem, 0);
-	
+
 	redo_menuitem = gtk_menu_item_new_with_mnemonic (_("_Redo"));
-	gtk_widget_set_sensitive (redo_menuitem, priv->can_redo);
+	gtk_widget_set_sensitive (redo_menuitem, lentry->can_redo);
 	g_signal_connect (redo_menuitem, "activate",
 			  G_CALLBACK (entry_redo_activate_cb), lentry);
 	gtk_widget_show (redo_menuitem);
 	gtk_menu_shell_insert (GTK_MENU_SHELL (menu), redo_menuitem, 1);
-	
+
 	separator = gtk_separator_menu_item_new ();
 	gtk_widget_show (separator);
 	gtk_menu_shell_insert (GTK_MENU_SHELL (menu), separator, 2);
@@ -672,7 +694,6 @@ static cairo_surface_t *
 favicon_create_drag_surface (EphyLocationEntry *entry,
 			     GtkWidget *widget)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
 	char *title = NULL, *address = NULL;
 	GString *text;
 	GtkStyleContext *style;
@@ -690,8 +711,6 @@ favicon_create_drag_surface (EphyLocationEntry *entry,
 	GdkRGBA color;
 	GdkPixbuf *favicon;
 
-	state = gtk_widget_get_state_flags (widget);
-
 	g_signal_emit (entry, signals[GET_LOCATION], 0, &address);
 	sanitize_location (&address);
 	g_signal_emit (entry, signals[GET_TITLE], 0, &title);
@@ -712,8 +731,8 @@ favicon_create_drag_surface (EphyLocationEntry *entry,
 		g_string_append (text, address);
 	}
 
-	if (priv->favicon != NULL)
-		favicon = g_object_ref (priv->favicon);
+	if (entry->favicon != NULL)
+		favicon = g_object_ref (entry->favicon);
 	else
 		favicon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
 						    "text-x-generic-symbolic",
@@ -729,8 +748,14 @@ favicon_create_drag_surface (EphyLocationEntry *entry,
 	layout = pango_layout_new (context);
 
 	style = gtk_widget_get_style_context (GTK_WIDGET (entry));
+	state = gtk_style_context_get_state (style);
+
+	gtk_style_context_save (style);
+	gtk_style_context_set_state (style, GTK_STATE_FLAG_NORMAL);
 	gtk_style_context_get (style, GTK_STATE_FLAG_NORMAL,
 			       "font", &font_desc, NULL);
+	gtk_style_context_restore (style);
+
 	metrics = pango_context_get_metrics (context,
 		                             font_desc,
 					     pango_context_get_language (context));
@@ -810,7 +835,7 @@ favicon_drag_begin_cb (GtkWidget *widget,
 	gint index;
 
 	entry = GTK_ENTRY (widget);
-	
+
 	index = gtk_entry_get_current_icon_drag_source (entry);
 	if (index != GTK_ENTRY_ICON_PRIMARY)
 		return;
@@ -856,19 +881,18 @@ icon_button_press_event_cb (GtkWidget *entry,
 {
 	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
 
-	if (event->type == GDK_BUTTON_PRESS && 
+	if (event->type == GDK_BUTTON_PRESS &&
 	    event->button == 1 &&
 	    state == 0 /* left */)
 	{
 		if (position == GTK_ENTRY_ICON_PRIMARY)
 		{
 			GtkWidget *toplevel;
-		
+
 			toplevel = gtk_widget_get_toplevel (GTK_WIDGET (entry));
 			gtk_window_set_focus (GTK_WINDOW (toplevel), entry);
 
-			gtk_editable_select_region (GTK_EDITABLE (entry), 
-						    0, -1);
+			gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
 		}
 		else
 		{
@@ -885,19 +909,18 @@ static void
 ephy_location_entry_construct_contents (EphyLocationEntry *lentry)
 {
 	GtkWidget *entry = GTK_WIDGET (lentry);
-	EphyLocationEntryPrivate *priv = lentry->priv;
 
 	LOG ("EphyLocationEntry constructing contents %p", lentry);
 
 	/* Favicon */
-	priv->drag_targets = gtk_target_list_new (url_drag_types,
+	lentry->drag_targets = gtk_target_list_new (url_drag_types,
 						  G_N_ELEMENTS (url_drag_types));
-	priv->drag_actions = GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK;
+	lentry->drag_actions = GDK_ACTION_ASK | GDK_ACTION_COPY | GDK_ACTION_LINK;
 
 	gtk_entry_set_icon_drag_source (GTK_ENTRY (entry),
 					GTK_ENTRY_ICON_PRIMARY,
-					priv->drag_targets,
-					priv->drag_actions);
+					lentry->drag_targets,
+					lentry->drag_actions);
 
 	gtk_entry_set_icon_tooltip_text (GTK_ENTRY (entry),
 					 GTK_ENTRY_ICON_PRIMARY,
@@ -930,18 +953,13 @@ ephy_location_entry_construct_contents (EphyLocationEntry *lentry)
 static void
 ephy_location_entry_init (EphyLocationEntry *le)
 {
-	EphyLocationEntryPrivate *p;
-
 	LOG ("EphyLocationEntry initialising %p", le);
 
-	p = EPHY_LOCATION_ENTRY_GET_PRIVATE (le);
-	le->priv = p;
-
-	p->user_changed = FALSE;
-	p->block_update = FALSE;
-	p->saved_text = NULL;
-	p->show_favicon = TRUE;
-	p->dns_prefetch_handler = 0;
+	le->user_changed = FALSE;
+	le->block_update = FALSE;
+	le->saved_text = NULL;
+	le->show_favicon = TRUE;
+	le->dns_prefetch_handler = 0;
 
 	ephy_location_entry_construct_contents (le);
 }
@@ -975,7 +993,7 @@ do_dns_prefetch (PrefetchHelper *helper)
 	if (helper->uri)
 		webkit_web_context_prefetch_dns (ephy_embed_shell_get_web_context (shell), helper->uri->host);
 
-	helper->entry->priv->dns_prefetch_handler = 0;
+	helper->entry->dns_prefetch_handler = 0;
 
 	return FALSE;
 }
@@ -992,18 +1010,18 @@ schedule_dns_prefetch (EphyLocationEntry *entry, guint interval, const gchar *ur
 		return;
 	}
 
-	if (entry->priv->dns_prefetch_handler)
-		g_source_remove (entry->priv->dns_prefetch_handler);
+	if (entry->dns_prefetch_handler)
+		g_source_remove (entry->dns_prefetch_handler);
 
 	helper = g_slice_new0 (PrefetchHelper);
 	helper->entry = g_object_ref (entry);
 	helper->uri = uri;
 
-	entry->priv->dns_prefetch_handler =
+	entry->dns_prefetch_handler =
 		g_timeout_add_full (G_PRIORITY_DEFAULT, interval,
 				    (GSourceFunc) do_dns_prefetch, helper,
 				    (GDestroyNotify) free_prefetch_helper);
-	g_source_set_name_by_id (entry->priv->dns_prefetch_handler, "[epiphany] do_dns_prefetch");
+	g_source_set_name_by_id (entry->dns_prefetch_handler, "[epiphany] do_dns_prefetch");
 }
 #endif
 
@@ -1017,17 +1035,17 @@ cursor_on_match_cb  (GtkEntryCompletion *completion,
 	GtkWidget *entry;
 
 	gtk_tree_model_get (model, iter,
-			    le->priv->url_col,
+			    le->url_col,
 			    &url, -1);
 	entry = gtk_entry_completion_get_entry (completion);
 
 	/* Prevent the update so we keep the highlight from our input.
 	 * See textcell_data_func().
 	 */
-	le->priv->block_update = TRUE;
+	le->block_update = TRUE;
 	gtk_entry_set_text (GTK_ENTRY (entry), url);
 	gtk_editable_set_position (GTK_EDITABLE (entry), -1);
-	le->priv->block_update = FALSE;
+	le->block_update = FALSE;
 
 #if 0
 /* FIXME: Refactor the DNS prefetch, this is a layering violation */
@@ -1041,18 +1059,17 @@ cursor_on_match_cb  (GtkEntryCompletion *completion,
 
 static void
 extracell_data_func (GtkCellLayout *cell_layout,
-			GtkCellRenderer *cell,
-			GtkTreeModel *tree_model,
-			GtkTreeIter *iter,
-			gpointer data)
+		     GtkCellRenderer *cell,
+		     GtkTreeModel *tree_model,
+		     GtkTreeIter *iter,
+		     gpointer data)
 {
-	EphyLocationEntryPrivate *priv;
+	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (data);
 	gboolean is_bookmark = FALSE;
 	GValue visible = { 0, };
 
-	priv = EPHY_LOCATION_ENTRY (data)->priv;
 	gtk_tree_model_get (tree_model, iter,
-			    priv->extra_col, &is_bookmark,
+			    entry->extra_col, &is_bookmark,
 			    -1);
 
 	if (is_bookmark)
@@ -1078,13 +1095,13 @@ extracell_data_func (GtkCellLayout *cell_layout,
  *
  **/
 void
-ephy_location_entry_set_match_func (EphyLocationEntry *entry, 
+ephy_location_entry_set_match_func (EphyLocationEntry *entry,
 				GtkEntryCompletionMatchFunc match_func,
 				gpointer user_data,
 				GDestroyNotify notify)
 {
 	GtkEntryCompletion *completion;
-	
+
 	completion = gtk_entry_get_completion (GTK_ENTRY (entry));
 	gtk_entry_completion_set_match_func (completion, match_func, user_data, notify);
 }
@@ -1120,15 +1137,14 @@ ephy_location_entry_set_completion (EphyLocationEntry *entry,
 {
 	GtkEntryCompletion *completion;
 	GtkCellRenderer *cell;
-	EphyLocationEntryPrivate *priv = entry->priv;
 
-	priv->text_col = text_col;
-	priv->action_col = action_col;
-	priv->keywords_col = keywords_col;
-	priv->relevance_col = relevance_col;
-	priv->url_col = url_col;
-	priv->extra_col = extra_col;
-	priv->favicon_col = favicon_col;
+	entry->text_col = text_col;
+	entry->action_col = action_col;
+	entry->keywords_col = keywords_col;
+	entry->relevance_col = relevance_col;
+	entry->url_col = url_col;
+	entry->extra_col = extra_col;
+	entry->favicon_col = favicon_col;
 
 	completion = gtk_entry_completion_new ();
 	gtk_entry_completion_set_model (completion, model);
@@ -1189,12 +1205,17 @@ ephy_location_entry_set_completion (EphyLocationEntry *entry,
 		 ICON_CONTENT_HEIGHT);
 	gtk_cell_renderer_set_alignment (cell, 0.0, 0.5);
 
-	cell = gtk_cell_renderer_text_new ();
-	g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+	cell = gd_two_lines_renderer_new ();
+	g_object_set (cell,
+                      "ellipsize", PANGO_ELLIPSIZE_END,
+                      "text-lines", 2,
+                      NULL);
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion),
 				    cell, TRUE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
-				       cell, "markup", text_col);
+				       cell, "text", text_col);
+        gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
+                                       cell, "line-two", url_col);
 
 	/* Pixel-perfect aligment with the text in the location entry.
 	 * See above.
@@ -1204,10 +1225,10 @@ ephy_location_entry_set_completion (EphyLocationEntry *entry,
 	gtk_cell_renderer_set_alignment (cell, 0.0, 0.5);
 
         /*
-         * As the width of the entry completion is known in advance 
-         * (as big as the entry you are completing on), we can set 
-         * any fixed width (the 1 is just this random number here). 
-         * Since the height is known too, we avoid computing the actual 
+         * As the width of the entry completion is known in advance
+         * (as big as the entry you are completing on), we can set
+         * any fixed width (the 1 is just this random number here)
+         * Since the height is known too, we avoid computing the actual
          * sizes of the cells, which takes a lot of CPU time and does
          * not get used anyway.
          */
@@ -1248,7 +1269,6 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 				  const char *address)
 {
 	GtkWidget *widget = GTK_WIDGET (entry);
-	EphyLocationEntryPrivate *priv = entry->priv;
 	GtkClipboard *clipboard;
 	const char *text;
 	char *effective_text = NULL, *selection = NULL;
@@ -1267,7 +1287,7 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 
 		if (gtk_clipboard_get_owner (clipboard) == G_OBJECT (widget) &&
 		    gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),
-	     					       &start, &end))
+		                                       &start, &end))
 		{
 			selection = gtk_editable_get_chars (GTK_EDITABLE (widget),
 							    start, end);
@@ -1282,8 +1302,8 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 		text = address;
 		gtk_entry_set_icon_drag_source (GTK_ENTRY (entry),
 						GTK_ENTRY_ICON_PRIMARY,
-						priv->drag_targets,
-						priv->drag_actions);
+						entry->drag_targets,
+						entry->drag_actions);
 	}
 	else
 	{
@@ -1295,11 +1315,11 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 	}
 
 	/* First record the new hash, then update the entry text */
-	priv->hash = g_str_hash (effective_text ? effective_text : text);
+	entry->hash = g_str_hash (effective_text ? effective_text : text);
 
-	priv->block_update = TRUE;
+	entry->block_update = TRUE;
 	gtk_entry_set_text (GTK_ENTRY (widget), effective_text ? effective_text : text);
-	priv->block_update = FALSE;
+	entry->block_update = FALSE;
 	g_free (effective_text);
 
 	/* We need to call update_address_state() here, as the 'changed' signal
@@ -1322,7 +1342,7 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
  * ephy_location_entry_get_can_undo:
  * @entry: an #EphyLocationEntry widget
  *
- * Wheter @entry can restore the displayed user modified text to the unmodified 
+ * Wheter @entry can restore the displayed user modified text to the unmodified
  * previous text.
  *
  * Return value: TRUE or FALSE indicating if the text can be restored
@@ -1331,9 +1351,7 @@ ephy_location_entry_set_location (EphyLocationEntry *entry,
 gboolean
 ephy_location_entry_get_can_undo (EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-	
-	return priv->user_changed;
+	return entry->user_changed;
 }
 
 /**
@@ -1349,9 +1367,7 @@ ephy_location_entry_get_can_undo (EphyLocationEntry *entry)
 gboolean
 ephy_location_entry_get_can_redo (EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-	
-	return priv->can_redo;
+	return entry->can_redo;
 }
 
 /**
@@ -1374,7 +1390,6 @@ static gboolean
 ephy_location_entry_reset_internal (EphyLocationEntry *entry,
 				    gboolean notify)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
 	const char *text, *old_text;
 	char *url = NULL;
 	gboolean retval;
@@ -1384,9 +1399,9 @@ ephy_location_entry_reset_internal (EphyLocationEntry *entry,
 	old_text = gtk_entry_get_text (GTK_ENTRY (entry));
 	old_text = old_text != NULL ? old_text : "";
 
-	g_free (priv->saved_text);
-	priv->saved_text = g_strdup (old_text);
-	priv->can_redo = TRUE;
+	g_free (entry->saved_text);
+	entry->saved_text = g_strdup (old_text);
+	entry->can_redo = TRUE;
 
 	retval = g_str_hash (text) != g_str_hash (old_text);
 
@@ -1397,8 +1412,8 @@ ephy_location_entry_reset_internal (EphyLocationEntry *entry,
 	{
 		g_signal_emit (entry, signals[USER_CHANGED], 0);
 	}
-	
-	priv->user_changed = FALSE;
+
+	entry->user_changed = FALSE;
 
 	return retval;
 }
@@ -1413,11 +1428,9 @@ ephy_location_entry_reset_internal (EphyLocationEntry *entry,
 void
 ephy_location_entry_undo_reset (EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-	
-	gtk_entry_set_text (GTK_ENTRY (entry), priv->saved_text);
-	priv->can_redo = FALSE;
-	priv->user_changed = TRUE;
+	gtk_entry_set_text (GTK_ENTRY (entry), entry->saved_text);
+	entry->can_redo = FALSE;
+	entry->user_changed = TRUE;
 }
 
 /**
@@ -1470,14 +1483,12 @@ void
 ephy_location_entry_set_favicon (EphyLocationEntry *entry,
 				 GdkPixbuf *pixbuf)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-
-	if (priv->favicon != NULL)
+	if (entry->favicon != NULL)
 	{
-		g_object_unref (priv->favicon);
+		g_object_unref (entry->favicon);
 	}
 
-	priv->favicon = pixbuf ? g_object_ref (pixbuf) : NULL;
+	entry->favicon = pixbuf ? g_object_ref (pixbuf) : NULL;
 
 	update_favicon (entry);
 }
@@ -1486,13 +1497,9 @@ void
 ephy_location_entry_set_show_favicon (EphyLocationEntry *entry,
 				      gboolean show_favicon)
 {
-	EphyLocationEntryPrivate *priv;
-
 	g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
 
-	priv = entry->priv;
-
-	priv->show_favicon = show_favicon != FALSE;
+	entry->show_favicon = show_favicon != FALSE;
 
 	update_favicon (entry);
 }
@@ -1550,7 +1557,5 @@ ephy_location_entry_set_lock_tooltip (EphyLocationEntry *entry,
 GSList *
 ephy_location_entry_get_search_terms (EphyLocationEntry *entry)
 {
-	EphyLocationEntryPrivate *priv = entry->priv;
-	
-	return priv->search_terms;
+	return entry->search_terms;
 }
