@@ -33,15 +33,13 @@
  * It can be used with #EphyNodeView and #EphyTreeModelFilter.
  */
 
-static void ephy_tree_model_node_class_init (EphyTreeModelNodeClass *klass);
-static void ephy_tree_model_node_init (EphyTreeModelNode *model);
 static void ephy_tree_model_node_finalize (GObject *object);
-static void ephy_tree_model_node_tree_model_init (GtkTreeModelIface *iface);
+static void ephy_tree_model_node_tree_model_interface_init (GtkTreeModelIface *iface);
 
-#define EPHY_TREE_MODEL_NODE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TREE_MODEL_NODE, EphyTreeModelNodePrivate))
-
-struct _EphyTreeModelNodePrivate
+struct _EphyTreeModelNode
 {
+	GObject parent_instance;
+
 	EphyNode *root;
 
 	GPtrArray *columns;
@@ -61,49 +59,15 @@ typedef struct
 enum
 {
 	PROP_0,
-	PROP_ROOT
+	PROP_ROOT,
+	LAST_PROP
 };
 
-static GObjectClass *parent_class = NULL;
+static GParamSpec *obj_properties[LAST_PROP];
 
-GType
-ephy_tree_model_node_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyTreeModelNodeClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) ephy_tree_model_node_class_init,
-			NULL,
-			NULL,
-			sizeof (EphyTreeModelNode),
-			0,
-			(GInstanceInitFunc) ephy_tree_model_node_init
-		};
-
-		const GInterfaceInfo tree_model_info =
-		{
-			(GInterfaceInitFunc) ephy_tree_model_node_tree_model_init,
-			NULL,
-			NULL
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "EphyTreeModelNode",
-					       &our_info, 0);
-
-		g_type_add_interface_static (type,
-					     GTK_TYPE_TREE_MODEL,
-					     &tree_model_info);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE_WITH_CODE (EphyTreeModelNode, ephy_tree_model_node, G_TYPE_OBJECT,
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
+                                                ephy_tree_model_node_tree_model_interface_init))
 
 static void
 root_child_removed_cb (EphyNode *node,
@@ -126,7 +90,7 @@ get_path_real (EphyTreeModelNode *model,
 	GtkTreePath *retval;
 
 	retval = gtk_tree_path_new ();
-	gtk_tree_path_append_index (retval, ephy_node_get_child_index (model->priv->root, node));
+	gtk_tree_path_append_index (retval, ephy_node_get_child_index (model->root, node));
 
 	return retval;
 }
@@ -197,7 +161,7 @@ static void
 root_destroy_cb (EphyNode *node,
 		 EphyTreeModelNode *model)
 {
-	model->priv->root = NULL;
+	model->root = NULL;
 
 	/* no need to do other stuff since we should have had a bunch of child_removed
 	 * signals already */
@@ -214,25 +178,25 @@ ephy_tree_model_node_set_property (GObject *object,
 	switch (prop_id)
 	{
 	case PROP_ROOT:
-		model->priv->root = g_value_get_pointer (value);
+		model->root = g_value_get_pointer (value);
 
-		ephy_node_signal_connect_object (model->priv->root,
+		ephy_node_signal_connect_object (model->root,
 				                 EPHY_NODE_CHILD_ADDED,
 				                 (EphyNodeCallback) root_child_added_cb,
 				                 G_OBJECT (model));
-		ephy_node_signal_connect_object (model->priv->root,
+		ephy_node_signal_connect_object (model->root,
 				                 EPHY_NODE_CHILD_REMOVED,
 				                 (EphyNodeCallback) root_child_removed_cb,
 				                 G_OBJECT (model));
-		ephy_node_signal_connect_object (model->priv->root,
+		ephy_node_signal_connect_object (model->root,
 				                 EPHY_NODE_CHILD_CHANGED,
 				                 (EphyNodeCallback) root_child_changed_cb,
 				                 G_OBJECT (model));
-		ephy_node_signal_connect_object (model->priv->root,
+		ephy_node_signal_connect_object (model->root,
 				                 EPHY_NODE_CHILDREN_REORDERED,
 				                 (EphyNodeCallback) root_children_reordered_cb,
 				                 G_OBJECT (model));
-		ephy_node_signal_connect_object (model->priv->root,
+		ephy_node_signal_connect_object (model->root,
 				                 EPHY_NODE_DESTROY,
 				                 (EphyNodeCallback) root_destroy_cb,
 				                 G_OBJECT (model));
@@ -255,7 +219,7 @@ ephy_tree_model_node_get_property (GObject *object,
 	switch (prop_id)
 	{
 	case PROP_ROOT:
-		g_value_set_pointer (value, model->priv->root);
+		g_value_set_pointer (value, model->root);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -268,8 +232,6 @@ ephy_tree_model_node_class_init (EphyTreeModelNodeClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = ephy_tree_model_node_finalize;
 
 	object_class->set_property = ephy_tree_model_node_set_property;
@@ -280,23 +242,21 @@ ephy_tree_model_node_class_init (EphyTreeModelNodeClass *klass)
 	*
 	* The root #EphyNode of the model.
 	*/
-	g_object_class_install_property (object_class,
-					 PROP_ROOT,
-					 g_param_spec_pointer ("root",
-							      "Root node",
-							      "Root node",
-							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
+	obj_properties[PROP_ROOT] =
+		g_param_spec_pointer ("root",
+		                      "Root node",
+		                      "Root node",
+		                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
-	g_type_class_add_private (object_class, sizeof (EphyTreeModelNodePrivate));
+	g_object_class_install_properties (object_class, LAST_PROP, obj_properties);
 }
 
 static void
 ephy_tree_model_node_init (EphyTreeModelNode *model)
 {
-	model->priv = EPHY_TREE_MODEL_NODE_GET_PRIVATE (model);
-	model->priv->stamp = g_random_int ();
-	model->priv->columns = g_ptr_array_new ();
-	model->priv->columns_num = 0;
+	model->stamp = g_random_int ();
+	model->columns = g_ptr_array_new ();
+	model->columns_num = 0;
 }
 
 static void
@@ -304,10 +264,10 @@ ephy_tree_model_node_finalize (GObject *object)
 {
 	EphyTreeModelNode *model = EPHY_TREE_MODEL_NODE (object);
 
-	g_ptr_array_foreach (model->priv->columns, (GFunc) g_free, NULL);
-	g_ptr_array_free (model->priv->columns, TRUE);
+	g_ptr_array_foreach (model->columns, (GFunc) g_free, NULL);
+	g_ptr_array_free (model->columns, TRUE);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_tree_model_node_parent_class)->finalize (object);
 }
 
 /**
@@ -327,8 +287,6 @@ ephy_tree_model_node_new (EphyNode *root)
 						    "root", root,
 						    NULL));
 
-	g_return_val_if_fail (model->priv != NULL, NULL);
-
 	return model;
 }
 
@@ -361,9 +319,9 @@ ephy_tree_model_node_add_column_full (EphyTreeModelNode *model,
 	col->func = func;
 	col->user_data = user_data;
 
-	g_ptr_array_add (model->priv->columns, col);
-	col_id = model->priv->columns_num;
-	model->priv->columns_num++;
+	g_ptr_array_add (model->columns, col);
+	col_id = model->columns_num;
+	model->columns_num++;
 
 	return col_id;
 }
@@ -412,7 +370,7 @@ ephy_tree_model_node_get_n_columns (GtkTreeModel *tree_model)
 {
 	EphyTreeModelNode *model = EPHY_TREE_MODEL_NODE (tree_model);
 
-	return model->priv->columns_num;
+	return model->columns_num;
 }
 
 static GType
@@ -422,7 +380,7 @@ ephy_tree_model_node_get_column_type (GtkTreeModel *tree_model,
 	EphyTreeModelNodeColData *col;
 	EphyTreeModelNode *model = EPHY_TREE_MODEL_NODE (tree_model);
 
-	col = g_ptr_array_index (model->priv->columns, index);
+	col = g_ptr_array_index (model->columns, index);
 
 	return col->type;
 }
@@ -439,14 +397,14 @@ ephy_tree_model_node_get_value (GtkTreeModel *tree_model,
 
 	g_return_if_fail (EPHY_IS_TREE_MODEL_NODE (tree_model));
 	g_return_if_fail (iter != NULL);
-	g_return_if_fail (iter->stamp == model->priv->stamp);
+	g_return_if_fail (iter->stamp == model->stamp);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return;
 
 	node = iter->user_data;
 
-	col = g_ptr_array_index (model->priv->columns, column);
+	col = g_ptr_array_index (model->columns, column);
 
 	g_return_if_fail (col != NULL);
 
@@ -486,13 +444,13 @@ ephy_tree_model_node_get_iter (GtkTreeModel *tree_model,
 	g_return_val_if_fail (EPHY_IS_TREE_MODEL_NODE (model), FALSE);
 	g_return_val_if_fail (gtk_tree_path_get_depth (path) > 0, FALSE);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return FALSE;
 
 	i = gtk_tree_path_get_indices (path)[0];
 
-	iter->stamp = model->priv->stamp;
-	iter->user_data = ephy_node_get_nth_child (model->priv->root, i);
+	iter->stamp = model->stamp;
+	iter->user_data = ephy_node_get_nth_child (model->root, i);
 
 	if (iter->user_data == NULL)
 	{
@@ -513,14 +471,14 @@ ephy_tree_model_node_get_path (GtkTreeModel *tree_model,
 	g_return_val_if_fail (EPHY_IS_TREE_MODEL_NODE (tree_model), NULL);
 	g_return_val_if_fail (iter != NULL, NULL);
 	g_return_val_if_fail (iter->user_data != NULL, NULL);
-	g_return_val_if_fail (iter->stamp == model->priv->stamp, NULL);
+	g_return_val_if_fail (iter->stamp == model->stamp, NULL);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return NULL;
 
 	node = iter->user_data;
 
-	if (node == model->priv->root)
+	if (node == model->root)
 		return gtk_tree_path_new ();
 
 	return get_path_real (model, node);
@@ -535,17 +493,17 @@ ephy_tree_model_node_iter_next (GtkTreeModel *tree_model,
 
 	g_return_val_if_fail (iter != NULL, FALSE);
 	g_return_val_if_fail (iter->user_data != NULL, FALSE);
-	g_return_val_if_fail (iter->stamp == model->priv->stamp, FALSE);
+	g_return_val_if_fail (iter->stamp == model->stamp, FALSE);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return FALSE;
 
 	node = iter->user_data;
 
-	if (node == model->priv->root)
+	if (node == model->root)
 		return FALSE;
 
-	iter->user_data = ephy_node_get_next_child (model->priv->root, node);
+	iter->user_data = ephy_node_get_next_child (model->root, node);
 
 	return (iter->user_data != NULL);
 }
@@ -557,14 +515,14 @@ ephy_tree_model_node_iter_children (GtkTreeModel *tree_model,
 {
 	EphyTreeModelNode *model = EPHY_TREE_MODEL_NODE (tree_model);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return FALSE;
 
 	if (parent != NULL)
 		return FALSE;
 
-	iter->stamp = model->priv->stamp;
-	iter->user_data = model->priv->root;
+	iter->stamp = model->stamp;
+	iter->user_data = model->root;
 
 	return TRUE;
 }
@@ -584,13 +542,13 @@ ephy_tree_model_node_iter_n_children (GtkTreeModel *tree_model,
 
 	g_return_val_if_fail (EPHY_IS_TREE_MODEL_NODE (tree_model), -1);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return 0;
 
 	if (iter == NULL)
-		return ephy_node_get_n_children (model->priv->root);
+		return ephy_node_get_n_children (model->root);
 
-	g_return_val_if_fail (model->priv->stamp == iter->stamp, -1);
+	g_return_val_if_fail (model->stamp == iter->stamp, -1);
 
 	return 0;
 }
@@ -606,17 +564,17 @@ ephy_tree_model_node_iter_nth_child (GtkTreeModel *tree_model,
 
 	g_return_val_if_fail (EPHY_IS_TREE_MODEL_NODE (tree_model), FALSE);
 
-	if (model->priv->root == NULL)
+	if (model->root == NULL)
 		return FALSE;
 
 	if (parent != NULL)
 		return FALSE;
 
-	node = ephy_node_get_nth_child (model->priv->root, n);
+	node = ephy_node_get_nth_child (model->root, n);
 
 	if (node != NULL)
 	{
-		iter->stamp = model->priv->stamp;
+		iter->stamp = model->stamp;
 		iter->user_data = node;
 		return TRUE;
 	}
@@ -661,12 +619,12 @@ ephy_tree_model_node_iter_from_node (EphyTreeModelNode *model,
 				     EphyNode *node,
 				     GtkTreeIter *iter)
 {
-	iter->stamp = model->priv->stamp;
+	iter->stamp = model->stamp;
 	iter->user_data = node;
 }
 
 static void
-ephy_tree_model_node_tree_model_init (GtkTreeModelIface *iface)
+ephy_tree_model_node_tree_model_interface_init (GtkTreeModelIface *iface)
 {
 	iface->get_flags       = ephy_tree_model_node_get_flags;
 	iface->get_iter        = ephy_tree_model_node_get_iter;
