@@ -53,9 +53,12 @@ enum
 	PROP_TOOLTIP,
 	PROP_LOCATION,
 	PROP_SMART_URL,
-	PROP_ICON
+	PROP_ICON,
+	LAST_PROP
 };
 
+static GParamSpec *obj_properties[LAST_PROP];
+
 typedef struct
 {
 	GObject *weak_ptr;
@@ -80,7 +83,7 @@ favicon_changed_cb (WebKitFaviconDatabase *database,
                 g_signal_handler_disconnect (database, action->priv->cache_handler);
                 action->priv->cache_handler = 0;
 
-                g_object_notify (G_OBJECT (action), "icon");
+                g_object_notify_by_pspec (G_OBJECT (action), obj_properties[PROP_ICON]);
         }
 }
 
@@ -166,14 +169,14 @@ ephy_bookmark_action_activate (EphyBookmarkAction *action,
 	location = ephy_node_get_property_string
 			(priv->node, EPHY_NODE_BMK_PROP_LOCATION);
 	g_return_if_fail (location != NULL);
-	
+
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
-	
+
 	if (GTK_IS_EDITABLE (widget))
 	{
 		text = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
 	}
-	
+
 	/* The entered search term is empty, and we have a smart bookmark */
 	if ((text == NULL || text[0] == '\0') && strstr (location, "%s") != NULL)
 	{
@@ -261,27 +264,27 @@ ephy_bookmark_action_updated (EphyBookmarkAction *action)
 	EphyNode *smart = ephy_bookmarks_get_smart_bookmarks (bookmarks);
 	EphyNode *node = action->priv->node;
 	const char *title;
-	
+
 	g_return_if_fail (action != NULL);
 	g_return_if_fail (node != NULL);
-	
+
 	g_object_freeze_notify (G_OBJECT (action));
 
 	/* Set smart_url */
 	action->priv->smart_url = ephy_node_has_child (smart, node);
-	g_object_notify (G_OBJECT (action), "smarturl");
-	
+	g_object_notify_by_pspec (G_OBJECT (action), obj_properties[PROP_SMART_URL]);
+
 	/* Set title */
 	title = ephy_node_get_property_string (node, EPHY_NODE_BMK_PROP_TITLE);
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_static_string (&value, title);
 	g_object_set_property (G_OBJECT (action), "label", &value);
 	g_value_unset (&value);
-	
+
 	/* Notify all other properties */
-	g_object_notify (G_OBJECT (action), "location");
-	g_object_notify (G_OBJECT (action), "icon");
-	
+	g_object_notify_by_pspec (G_OBJECT (action), obj_properties[PROP_LOCATION]);
+	g_object_notify_by_pspec (G_OBJECT (action), obj_properties[PROP_ICON]);
+
 	g_object_thaw_notify (G_OBJECT (action));
 
 	/* We could force a tooltip re-query with gtk_tooltip_trigger_tooltip_query
@@ -309,7 +312,7 @@ ephy_bookmark_action_set_bookmark (EphyBookmarkAction *action,
 
 	g_object_freeze_notify (object);
 
-	g_object_notify (object, "bookmark");
+	g_object_notify_by_pspec (G_OBJECT (action), obj_properties[PROP_BOOKMARK]);
 	ephy_bookmark_action_updated (action);
 
 	g_object_thaw_notify (object);
@@ -334,6 +337,8 @@ ephy_bookmark_action_set_property (GObject *object,
 		case PROP_ICON:
 			/* not writable */
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	}
 }
 
@@ -367,6 +372,8 @@ ephy_bookmark_action_get_property (GObject *object,
 				ephy_node_get_property_string (priv->node,
 					EPHY_NODE_BMK_PROP_ICON));
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	}
 }
 
@@ -374,7 +381,7 @@ static void
 ephy_bookmark_action_init (EphyBookmarkAction *action)
 {
 	action->priv = EPHY_BOOKMARK_ACTION_GET_PRIVATE (action);
-	
+
 	action->priv->cache_handler = 0;
 }
 
@@ -410,34 +417,29 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 	object_class->set_property = ephy_bookmark_action_set_property;
 	object_class->get_property = ephy_bookmark_action_get_property;
 
-	g_object_class_install_property (object_class,
-					 PROP_BOOKMARK,
-					 g_param_spec_pointer ("bookmark", NULL, NULL,
-							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
-							       G_PARAM_CONSTRUCT_ONLY));
+	obj_properties[PROP_BOOKMARK] =
+		g_param_spec_pointer ("bookmark", NULL, NULL,
+		                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_CONSTRUCT_ONLY);
 
 	/* overwrite GtkActionClass::tooltip, so we can use the url as tooltip */
-	g_object_class_install_property (object_class,
-					 PROP_TOOLTIP,
-					 g_param_spec_string  ("tooltip", NULL, NULL,
-							       NULL,
-							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-	
-	g_object_class_install_property (object_class,
-					 PROP_LOCATION,
-					 g_param_spec_string  ("location", NULL, NULL,
-							       NULL,
-							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-	g_object_class_install_property (object_class,
-					 PROP_SMART_URL,
-					 g_param_spec_boolean  ("smarturl", NULL, NULL,
-								FALSE,
-								G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-	g_object_class_install_property (object_class,
-					 PROP_ICON,
-					 g_param_spec_string  ("icon", NULL, NULL,
-							       NULL,
-							       G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	obj_properties[PROP_TOOLTIP] =
+		g_param_spec_string  ("tooltip", NULL, NULL,
+		                      NULL,
+		                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+	obj_properties[PROP_LOCATION] =
+		g_param_spec_string  ("location", NULL, NULL,
+		                      NULL,
+		                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+	obj_properties[PROP_SMART_URL] =
+		g_param_spec_boolean  ("smarturl", NULL, NULL,
+		                       FALSE,
+		                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+	obj_properties[PROP_ICON] =
+		g_param_spec_string  ("icon", NULL, NULL,
+		                      NULL,
+		                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties (object_class, LAST_PROP, obj_properties);
 
 	g_type_class_add_private (object_class, sizeof(EphyBookmarkActionPrivate));
 }
