@@ -14,9 +14,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -328,7 +326,7 @@ ephy_bookmarks_ui_add_bookmark (GtkWindow *parent,
 }
 
 void
-ephy_bookmarks_ui_show_bookmark (EphyNode *bookmark)
+ephy_bookmarks_ui_show_bookmark (GtkWindow *parent, EphyNode *bookmark)
 {
 	EphyBookmarks *bookmarks;
 	GtkWidget *dialog;
@@ -355,6 +353,8 @@ ephy_bookmarks_ui_show_bookmark (EphyNode *bookmark)
 				     bookmark, dialog);
 	}
 
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
+
 	gtk_window_present_with_time (GTK_WINDOW (dialog),
 				      gtk_get_current_event_time ());
 }
